@@ -163,12 +163,39 @@ class R(object):
             result['Uncategorized'] = uncategorized
         return result
 
-    def metric(self, slug, num=1, category=None):
+    def delete_metric(self, slug):
+        """Removes all keys for the given ``slug``."""
+
+        # To remove all keys for a slug, I need to retrieve them all from
+        # the set of metric keys, then filter the matching prefixes.
+        # This is quite possibly the most inefficient way to do this :-/
+        prefix = "m:{0}:".format(slug)
+        keys = [
+            k for k in self.r.smembers(self._metric_slugs_key)
+            if k.startswith(prefix)
+        ]
+
+        # Remove the metric data
+        self.r.delete(*keys)
+
+        # Finally, remove keys from the set
+        self.r.srem(self._metric_slugs_key, *keys)
+
+    def metric(self, slug, num=1, category=None, expire=None):
         """Records a metric, creating it if it doesn't exist or incrementing it
         if it does. All metrics are prefixed with 'm', and automatically
         aggregate for Day, Week, Month, and Year.
 
-        Keys for each metric (slug) take the form:
+        Parameters:
+
+        * ``slug`` -- a unique value to identify the metric; used in
+          construction of redis keys (see below).
+        * ``num`` -- Set or Increment the metric by this number; default is 1.
+        * ``category`` -- (optional) Assign the metric to a Category (a string)
+        * ``expire`` -- (optional) Specify the number of seconds in which the
+          metric will expire.
+
+        Redis keys for each metric (slug) take the form:
 
             m:<slug>:<yyyy-mm-dd>   # Day
             m:<slug>:w:<yyyy-num>   # Week (year - week number)
@@ -192,6 +219,13 @@ class R(object):
         if category:
             self._categorize(slug, category)
 
+        # Expire the Metric in ``expire`` seconds
+        if expire:
+            self.r.expire(day_key, expire)
+            self.r.expire(week_key, expire)
+            self.r.expire(month_key, expire)
+            self.r.expire(year_key, expire)
+
     def get_metric(self, slug):
         """Get the current values for a metric.
 
@@ -354,6 +388,12 @@ class R(object):
         return "g:{0}".format(slugify(slug))
 
     def gauge(self, slug, current_value):
+        """Set the value for a Gauge.
+
+        * ``slug`` -- the unique identifier (or key) for the Gauge
+        * ``current_value`` -- the value that the gauge should display
+
+        """
         k = self._gauge_key(slug)
         self.r.sadd(self._gauge_slugs_key, k)  # keep track of all Gauges
         self.r.set(k, current_value)
@@ -361,3 +401,9 @@ class R(object):
     def get_gauge(self, slug):
         k = self._gauge_key(slug)
         return self.r.get(k)
+
+    def delete_gauge(self, slug):
+        """Removes all gauges with the given ``slug``."""
+        key = self._gauge_key(slug)
+        self.r.delete(key)  # Remove the Gauge
+        self.r.srem(self._gauge_slugs_key, key)  # Remove from the set of keys
