@@ -41,27 +41,30 @@ class ProtectedFormView(FormView):
         return super(ProtectedFormView, self).dispatch(*args, **kwargs)
 
 
+class DefaultView(ProtectedTemplateView):
+    template_name = "redis_metrics/default.html"
+
+
+class GaugesView(ProtectedTemplateView):
+    template_name = "redis_metrics/gauges.html"
+
+    def get_context_data(self, **kwargs):
+        """Includes the Gauge slugs and data in the context."""
+        data = super(GaugesView, self).get_context_data(**kwargs)
+        data.update({'gauges': R().gauge_slugs()})
+        return data
+
+
 class MetricsListView(ProtectedTemplateView):
     template_name = "redis_metrics/metrics_list.html"
 
     def get_context_data(self, **kwargs):
         """Includes the metrics slugs in the context."""
         data = super(MetricsListView, self).get_context_data(**kwargs)
-        r = R()
+
         # Metrics organized by category, like so:
         # { <category_name>: [ <slug1>, <slug2>, ... ]}
-        data['metrics'] = r.metric_slugs_by_category()
-
-        # Include gauges in the default View. They're *technically* a list
-        # of metrics, too!
-        gauges = {
-            'slugs': list(r.gauge_slugs()),
-            'data': {}
-        }
-        if gauges['slugs']:
-            for slug in gauges['slugs']:
-                gauges['data'][slug] = r.get_gauge(slug)
-        data['gauges'] = gauges
+        data.update({'metrics': R().metric_slugs_by_category()})
         return data
 
 
